@@ -364,93 +364,6 @@ e_mail_identity_combo_box_new (ESourceRegistry *registry)
 		"registry", registry, NULL);
 }
 
-static gint
-compare_identity_sources_cb (gconstpointer aa,
-			     gconstpointer bb,
-			     gpointer user_data)
-{
-	ESource *a_source = (ESource *) aa;
-	ESource *b_source = (ESource *) bb;
-	GHashTable *indexes = user_data;
-	gint a_index = 0, b_index = 0;
-
-	if (indexes && e_source_get_uid (a_source) && e_source_get_uid (b_source)) {
-		a_index = GPOINTER_TO_INT (g_hash_table_lookup (indexes, e_source_get_uid (a_source)));
-		if (!a_index && e_source_get_parent (a_source))
-			a_index = GPOINTER_TO_INT (g_hash_table_lookup (indexes, e_source_get_parent (a_source)));
-
-		b_index = GPOINTER_TO_INT (g_hash_table_lookup (indexes, e_source_get_uid (b_source)));
-		if (!b_index && e_source_get_parent (b_source))
-			b_index = GPOINTER_TO_INT (g_hash_table_lookup (indexes, e_source_get_parent (b_source)));
-	}
-
-	if (a_index == b_index) {
-		ESourceMailIdentity *a_identity = e_source_get_extension (a_source, E_SOURCE_EXTENSION_MAIL_IDENTITY);
-		ESourceMailIdentity *b_identity = e_source_get_extension (b_source, E_SOURCE_EXTENSION_MAIL_IDENTITY);
-		const gchar *a_value, *b_value;
-
-		b_index = 0;
-
-		a_value = e_source_mail_identity_get_name (a_identity);
-		b_value = e_source_mail_identity_get_name (b_identity);
-
-		a_index = (a_value && b_value) ? g_utf8_collate (a_value, b_value) : g_strcmp0 (a_value, b_value);
-
-		if (!a_index) {
-			a_index = g_strcmp0 (e_source_mail_identity_get_address (a_identity),
-					     e_source_mail_identity_get_address (b_identity));
-		}
-	}
-
-	return a_index - b_index;
-}
-
-/* This is in e-util/, compiled before mail/, thus cannot reach EMailAccountStore,
-   thus copy the code. */
-static GList * /* ESource * */
-mail_identity_combo_box_sort_sources (GList *sources) /* ESource * */
-{
-	gchar *sort_order_filename;
-	GHashTable *indexes; /* gchar *uid ~> gint index */
-
-	if (!sources)
-		return sources;
-
-	indexes = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
-
-	sort_order_filename = g_build_filename (e_get_user_config_dir (), "mail", "sortorder.ini", NULL);
-	if (g_file_test (sort_order_filename, G_FILE_TEST_IS_REGULAR)) {
-		GKeyFile *key_file;
-
-		key_file = g_key_file_new ();
-		if (g_key_file_load_from_file (key_file, sort_order_filename, G_KEY_FILE_NONE, NULL)) {
-			gchar **service_uids;
-			gsize ii, length;
-
-			service_uids = g_key_file_get_string_list (key_file, "Accounts", "SortOrder", &length, NULL);
-
-			for (ii = 0; ii < length; ii++) {
-				const gchar *uid = service_uids[ii];
-
-				if (uid && *uid)
-					g_hash_table_insert (indexes, g_strdup (uid), GINT_TO_POINTER (ii + 1));
-			}
-
-			g_strfreev (service_uids);
-		}
-
-		g_key_file_free (key_file);
-	}
-
-	g_free (sort_order_filename);
-
-	sources = g_list_sort_with_data (sources, compare_identity_sources_cb, indexes);
-
-	g_hash_table_destroy (indexes);
-
-	return sources;
-}
-
 static gchar *
 mail_identity_combo_box_build_alias_id (const gchar *identity_uid,
 					const gchar *name,
@@ -458,7 +371,7 @@ mail_identity_combo_box_build_alias_id (const gchar *identity_uid,
 {
 	g_return_val_if_fail (identity_uid != NULL, NULL);
 
-	if (!address || !*address)
+	if (!address)
 		return g_strdup (identity_uid);
 
 	return g_strconcat (identity_uid, "\n", address, "\n", name, NULL);
@@ -470,7 +383,6 @@ mail_identity_combo_box_add_address (GtkListStore *list_store,
 				     const gchar *name,
 				     const gchar *address,
 				     gboolean is_alias_entry,
-				     const gchar *stored_alias_name,
 				     const gchar *identity_uid,
 				     const gchar *identity_display_name)
 {
@@ -497,7 +409,7 @@ mail_identity_combo_box_add_address (GtkListStore *list_store,
 	if (queue != NULL && g_queue_get_length (queue) > 1)
 		g_string_append_printf (string, " (%s)", identity_display_name);
 
-	alias_id = mail_identity_combo_box_build_alias_id (identity_uid, stored_alias_name, address);
+	alias_id = mail_identity_combo_box_build_alias_id (identity_uid, name, address);
 
 	gtk_list_store_append (list_store, &iter);
 
@@ -558,8 +470,6 @@ e_mail_identity_combo_box_refresh (EMailIdentityComboBox *combo_box)
 	registry = e_mail_identity_combo_box_get_registry (combo_box);
 	list = e_source_registry_list_enabled (registry, extension_name);
 
-	list = mail_identity_combo_box_sort_sources (list);
-
 	/* Build a hash table of GQueues by email address so we can
 	 * spot duplicate email addresses.  Then if the GQueue for a
 	 * given email address has multiple elements, we use a more
@@ -641,7 +551,7 @@ e_mail_identity_combo_box_refresh (EMailIdentityComboBox *combo_box)
 		address = e_source_mail_identity_get_address (extension);
 
 		mail_identity_combo_box_add_address (GTK_LIST_STORE (tree_model),
-			address_table, name, address, FALSE, NULL, uid, display_name);
+			address_table, name, address, FALSE, uid, display_name);
 
 		if (!e_mail_identity_combo_box_get_allow_aliases (combo_box))
 			continue;
@@ -660,10 +570,10 @@ e_mail_identity_combo_box_refresh (EMailIdentityComboBox *combo_box)
 				if (camel_internet_address_get (inet_address, ii, &alias_name, &alias_address) &&
 				    alias_address && *alias_address) {
 					if (!alias_name || !*alias_name)
-						alias_name = NULL;
+						alias_name = name;
 
 					mail_identity_combo_box_add_address (GTK_LIST_STORE (tree_model),
-						address_table, alias_name ? alias_name : name, alias_address, TRUE, alias_name, uid, display_name);
+						address_table, alias_name, alias_address, TRUE, uid, display_name);
 				}
 			}
 
@@ -899,33 +809,6 @@ e_mail_identity_combo_box_set_active_uid (EMailIdentityComboBox *combo_box,
 
 	g_free (alias_id);
 
-	if (!found && alias_address && *alias_address) {
-		/* Match the first alias_address, not considering the name at all */
-		GtkTreeModel *model;
-		GtkTreeIter iter;
-
-		model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo_box));
-		if (gtk_tree_model_get_iter_first (model, &iter)) {
-			do {
-				gchar *uid = NULL, *address = NULL;
-
-				gtk_tree_model_get (model, &iter,
-					E_MAIL_IDENTITY_COMBO_BOX_COLUMN_UID, &uid,
-					E_MAIL_IDENTITY_COMBO_BOX_COLUMN_ADDRESS, &address,
-					-1);
-
-				found = g_strcmp0 (uid, identity_uid) == 0 &&
-					address && g_ascii_strcasecmp (address, alias_address) == 0;
-
-				g_free (uid);
-				g_free (address);
-
-				if (found)
-					gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo_box), &iter);
-			} while (!found && gtk_tree_model_iter_next (model, &iter));
-		}
-	}
-
 	if (!found && alias_address)
 		found = gtk_combo_box_set_active_id (GTK_COMBO_BOX (combo_box), identity_uid);
 
