@@ -183,10 +183,6 @@ static const char introspection_xml[] =
 "      <arg type='b' name='towards_bottom' direction='in'/>"
 "      <arg type='b' name='processed' direction='out'/>"
 "    </method>"
-"    <method name='EWebViewEnsureBodyClass'>"
-"      <arg type='t' name='page_id' direction='in'/>"
-"      <arg type='s' name='body_class' direction='in'/>"
-"    </method>"
 "    <signal name='NeedInputChanged'>"
 "      <arg type='t' name='page_id' direction='out'/>"
 "      <arg type='b' name='need_input' direction='out'/>"
@@ -853,7 +849,6 @@ handle_method_call (GDBusConnection *connection,
 			return;
 
 		document = webkit_web_page_get_dom_document (web_page);
-		e_dom_utils_e_mail_display_unstyle_blockquotes (document);
 		e_dom_utils_e_mail_display_bind_dom (document, connection);
 		e_web_extension_bind_focus_on_elements (extension, document);
 
@@ -1022,22 +1017,6 @@ handle_method_call (GDBusConnection *connection,
 		}
 
 		g_dbus_method_invocation_return_value (invocation, g_variant_new ("(b)", processed));
-	} else if (g_strcmp0 (method_name, "EWebViewEnsureBodyClass") == 0) {
-		const gchar *body_class = NULL;
-		WebKitDOMHTMLElement *body;
-
-		g_variant_get (parameters, "(t&s)", &page_id, &body_class);
-		web_page = get_webkit_web_page_or_return_dbus_error (invocation, web_extension, page_id);
-		if (!web_page)
-			return;
-
-		document = webkit_web_page_get_dom_document (web_page);
-
-		body = webkit_dom_document_get_body (document);
-		if (body && !webkit_dom_element_has_attribute (WEBKIT_DOM_ELEMENT (body), "class"))
-			webkit_dom_element_set_class_name (WEBKIT_DOM_ELEMENT (body), body_class);
-
-		g_dbus_method_invocation_return_value (invocation, NULL);
 	}
 }
 
@@ -1201,32 +1180,20 @@ web_page_send_request_cb (WebKitWebPage *web_page,
 	return FALSE;
 }
 
-static void
-e_web_extension_store_page_id_on_document (WebKitWebPage *web_page)
-{
-	WebKitDOMDocument *document;
-	guint64 *ppage_id;
-
-	g_return_if_fail (WEBKIT_IS_WEB_PAGE (web_page));
-
-	ppage_id = g_new (guint64, 1);
-	*ppage_id = webkit_web_page_get_id (web_page);
-
-	document = webkit_web_page_get_dom_document (web_page);
-
-	g_object_set_data_full (G_OBJECT (document), WEB_EXTENSION_PAGE_ID_KEY, ppage_id, g_free);
-}
-
 static void
 web_page_document_loaded_cb (WebKitWebPage *web_page,
                              gpointer user_data)
 {
 	WebKitDOMDocument *document;
-
-	e_web_extension_store_page_id_on_document (web_page);
+	guint64 *ppage_id;
 
 	document = webkit_web_page_get_dom_document (web_page);
 
+	ppage_id = g_new (guint64, 1);
+	*ppage_id = webkit_web_page_get_id (web_page);
+
+	g_object_set_data_full (G_OBJECT (document), WEB_EXTENSION_PAGE_ID_KEY, ppage_id, g_free);
+
 	e_dom_utils_replace_local_image_links (document);
 
 	if ((webkit_dom_document_query_selector (
@@ -1315,8 +1282,6 @@ web_page_created_cb (WebKitWebExtension *wk_extension,
 	page_data->need_input = FALSE;
 	page_data->clipboard_flags = 0;
 
-	e_web_extension_store_page_id_on_document (web_page);
-
 	g_hash_table_insert (extension->priv->pages, ppage_id, page_data);
 
 	g_object_weak_ref (G_OBJECT (web_page), web_page_gone_cb, extension);
